| License | BSD-3-Clause |
|---|---|
| Maintainer | Jamie Willis, Gigaparsec Maintainers |
| Stability | experimental |
| Safe Haskell | Trustworthy |
| Language | Haskell2010 |
Text.Gigaparsec.Patterns
Description
This module is currently experimental, and may have bugs depending on the version of Haskell, or the extensions enabled. Please report any issues to the maintainers.
Since: 0.2.2.0